Adapay Python SDK
===================================

 Adapay Python SDK。

安装
-----
如果已下载至本地：
pip install local_sdk_path

远程下载并安装：
pip install adapay

API 文档
--------------------

- https://docs.adapay.tech/api/index.html

SDK 文档
--------------------

- https://docs.adapay.tech/sdk/pythonsdkaccess.html
